#
# spec file for package libmatroska
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 7
Name:           libmatroska
Version:        1.7.1
Release:        1.8
Summary:        Library to Deal with Matroska Files
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://www.matroska.org/
#Git-Clone:	git://github.com/Matroska-Org/libmatroska
#Git-Web:	https://github.com/Matroska-Org/libmatroska
Source0:        https://dl.matroska.org/downloads/libmatroska/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
Source99:       %{name}.changes
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libebml) >= 1.4.4

%description
Libmatroska is a C++ library to parse Matroska files (.mkv and .mka).
It depends on libebml to work. You only need this package to compile
your own applications.

%package -n libmatroska%{sover}
Summary:        Library to Deal with Matroska Files
Group:          System/Libraries

%description -n libmatroska%{sover}
Libmatroska is a C++ library to parse Matroska files (.mkv and .mka).
It depends on libebml to work. You only need this package to compile
your own applications.

%package devel
Summary:        Library to Deal with Matroska Files
Group:          Development/Libraries/C and C++
Requires:       libmatroska%{sover} = %{version}
Requires:       pkgconfig(libebml) >= 1.4.2

%description devel
Libmatroska is a C++ library to parse Matroska files (.mkv and .mka).
It depends on libebml to work. You only need this package to compile
your own applications.

%prep
%autosetup

%build
# mkvmerge-9.3.0 built against libmatroska-1.4.5 running against
# libmatroska-1.4.4: symbol lookup error: mkvmerge: undefined symbol:
# _ZN11libmatroska14KaxVideoColour10ClassInfosE
# Force some additional versioning, since upstream did not track the ABI
# changes.
# Tag with the version of the most recent !!incompatible!! change.
echo "V_1.7.0 { global: *; };" > libmatroska.sym
export LDFLAGS="-Wl,--version-script=$PWD/libmatroska.sym"
%cmake \
	-DCMAKE_SHARED_LINKER_FLAGS="$LDFLAGS -Wl,--as-needed -Wl,--no-undefined -Wl,-z,now"
%cmake_build

%install
%cmake_install

%post -n libmatroska%{sover} -p /sbin/ldconfig
%postun -n libmatroska%{sover} -p /sbin/ldconfig

%files -n libmatroska%{sover}
%{_libdir}/libmatroska.so.%{sover}*

%files devel
%{_libdir}/libmatroska.so
%{_libdir}/pkgconfig/*.pc
%{_libdir}/cmake/Matroska
%{_includedir}/matroska

%changelog
* Sun Oct  9 2022 C J <c.j@tuta.io>
- update to 1.7.1:
  * Fix ABI compatibility: unfortunately release 1.7.0 broke ABI
    compatibility. This release restores the compatibility with
    release 1.6.3. Please use it instead of release 1.7.0. In other
    words: 1.6.3 & 1.7.1 are compatible, while 1.7.0 is compatible
    with neither 1.6.3 nor 1.7.1.
* Fri Oct  7 2022 Dirk Müller <dmueller@suse.com>
- update to 1.7.0:
  * A C++14 compliant C++ compiler is now required.
  * libEBML v1.4.3 is now required.
  * Remove Coremake project files
  * Add `KaxInternalBlock::GetRelativeTimestamp()` to access unscaled
    block timestamps.
  * Fixed problems with the generated `pkg-config` files if any of the
    installation paths are absolute.
  * Added several enums in `namespace libmatroska` for the various
    elements that are constrained to a set of options:
    `MatroskaTrackType`, `MatroskaTrackEncodingCompAlgo`,
    `MatroskaChapterTranslateCodec`, `MatroskaTrackTranslateCodec`,
    `MatroskaVideoFlagInterlaced`, `MatroskaVideoFieldOrder`,
    `MatroskaVideoStereoMode`, `MatroskaVideoAlphaMode`,
    `MatroskaVideoOldStereoMode`, `MatroskaVideoDisplayUnit`,
    `MatroskaVideoAspectRatioType`, `MatroskaVideoMatrixCoefficients`,
    `MatroskaColourChromaSitingHorz`, `MatroskaColourChromaSitingVert`,
    `MatroskaVideoRange`, `MatroskaVideoTransferCharacteristics`,
    `MatroskaVideoPrimaries`, `MatroskaVideoProjectionType`,
    `MatroskaAudioEmphasis`, `MatroskaTrackPlaneType`,
    `MatroskaContentEncodingScope`, `MatroskaContentEncodingType`,
    `MatroskaContentEncodingAlgo`, `MatroskaAESSettingsCipherMode`,
    `MatroskaContentSignatureAlgo`, `MatroskaContentSigHashAlgo`,
    `MatroskaChapterSkipType`, `MatroskaChapterProcessTime` and
    `MatroskaTargetTypeValue`.
  * Updated the semantics to the latest specifications, deprecating the
    following elements by preventing code to write them:
    `KaxClusterSilentTracks`, `KaxClusterSilentTrackNumber`,
    `KaxSlices`, `KaxReferenceFrame`, `KaxReferenceOffset`,
    `KaxReferenceTimeCode`, `KaxTrackTimecodeScale`,
    `KaxCodecDecodeAll`, `KaxVideoAspectRatio`, `KaxTrickTrackUID`,
    `KaxTrickTrackSegmentUID`, `KaxTrickTrackFlag`,
    `KaxTrickMasterTrackUID`, `KaxTrickMasterTrackSegmentUID`,
    `KaxContentSignature`, `KaxContentSigKeyID`, `KaxContentSigAlgo` and
    `KaxContentSigHashAlgo`.
  * Updated the semantics to the latest specifications, making the
    following elements mandatory (but having default values):
    `KaxCodecDelay`, `KaxVideoPixelCropBottom`, `KaxVideoPixelCropTop`,
    `KaxVideoPixelCropLeft`, `KaxVideoPixelCropRight`,
    `KaxVideoBitsPerChannel`, `KaxCueCodecState`,
    `KaxTagTargetTypeValue`, `KaxTrackLanguage`, `KaxVideoStereoMode`,
    `KaxVideoAlphaMode`, `KaxEditionFlagOrdered`,
    `KaxVideoChromaSitHorz`, `KaxVideoChromaSitVert`,
    `KaxVideoColourRange`, `KaxVideoColourMatrix`,
    `KaxVideoColourTransferCharacter`, `KaxVideoColourPrimaries` and
    `KaxVideoDisplayUnit`.
  * Updated the semantics to the latest specifications, removing the
    default values from the following elements: `KaxCueBlockNumber`,
    `KaxFlagHearingImpaired`, `KaxFlagVisualImpaired`,
    `KaxFlagTextDescriptions`, and `KaxFlagOriginal`.
  * Updated the semantics to the latest specifications, adding the
    following new elements: `TagDefaultBogus` (as a placeholder for
    accidentally used but wrong EBML ID 0x44b4), `KaxEmphasis`,
* Tue Feb 23 2021 Dirk Müller <dmueller@suse.com>
- update to 1.6.3:
  * libEBML v1.4.2 is now required.
  * Added classes for new track header elements:
  "KaxFlagHearingImpaired", "KaxFlagVisualImpaired",
  "KaxFlagTextDescriptions", "KaxFlagOriginal" and
  "KaxFlagCommentary".
* Sun Aug  2 2020 aloisio@gmx.com
- Update to version 1.6.2
  * In release 1.6.1 the version number in CMakeLists.txt wasn't
    updated, affecting the installed cmake and pkgconfig files.
    The version number has been bumped to 1.6.2 in all relevant
    files now.
* Sun Aug  2 2020 aloisio@gmx.com
- Update to version 1.6.1
  * "KaxBlockAddIDValue" class: this class is no longer marked as
    "mandatory" in order to coincide with the latest
    specification.
* Sun Jun 28 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.6.0
  * libEBML v1.4.0 is now required.
  * Due to breaking ABI the soname version has been bumped to
    7.0.0.
  * Default symbol visibility is now "hidden", reducing binary
    size.
  * Converted some things pointed out by cppcheck & clang-tidy to
    C++11.
  * Fixed a lot of issues pointed out by clang-tidy.
  * A C++11 compliant compiler is now required. Several of its
    features are now used in the source.
  * "KaxCueData" class: added "PositionSet" overrides taking
    "KaxSimpleBlock" arguments.
  * "KaxSeekHead" class: the "IndexThis" function now returns a
    pointer to the newly allocated "KaxSeek" instance.
  * "KaxBlockData" class: the "SetReferencedTimecode" function is
    now public.
  * Fixed classes for updates in the current specification:
    KaxTrackTimecodeScale (can be written again), TimeSlice,
    SliceLaceNumber, TrackAttachmentLink (these cannot be written
    anymore), KaxContentEncAlgo (it's mandatory),
    KaxChapLanguageIETF (can occur multiple times),
    KaxFileUsedStartTime, KaxFileUsedEndTime (DivX-related
    elements, cannot be written anymore)
  * Added classes for new elements from the current
    specification: KaxBlockAdditionMapping, KaxBlockAddIDValue,
    KaxBlockAddIDName, KaxBlockAddIDType, KaxBlockAddIDExtraData,
    KaxContentEncAESSettings, KaxContentEncAESSettings.
  * The MATROSKA_VERSION pre-processor definition has been
    removed. You used to be able toe restrict compiling with only
    those classes for elements contained in Matroska v1, but that
    hasn't worked since 2010, so… yeah.
- Track ABI Change
- Spec cleanup
* Wed Jul 10 2019 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.5.2:
  * Fix boo#1141027
  * KaxBlock: fixed a potential access to invalid memory due to
    invalid lace sizes read from invalid data.
  * KaxBlock: fixed a potential null pointer dereference triggerable
    by reading invalid data.
* Tue Apr 16 2019 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 1.5.0:
  * Compatibilty with libEBML 1.3.7
* Thu Aug  9 2018 rpm@fthiessen.de
- Fixed ABI tracking with cmake macro.
* Mon Jul 30 2018 rpm@fthiessen.de
- Update to version 1.4.9:
  * Switched to cmake.
* Sat Mar 10 2018 rpm@fthiessen.de
- Track ABI Change, since 1.4.7 is incompatible with lower versions.
* Mon Oct  9 2017 zaitor@opensuse.org
- Update to version 1.4.8:
  * KaxBlockGroup, KaxSimpleBlock: fixed writing the block header
    if the track number is 128.
* Mon Jun 26 2017 zaitor@opensuse.org
- Update to version 1.4.7:
  * Setting the version number in the "KaxCodeVersion" variable
    correctly.
- Changes from version 1.4.6:
  * KaxSemantic: add new elements dealing with 360°/VR content and
    for language descriptors based on IETF BPC 47.
* Fri Jul 22 2016 rpm@fthiessen.de
- As the upstream does not track ABI changes we had to add some
  additional version tracking.
* Fri Jul 15 2016 jengelh@inai.de
- Fix messed-up FAKE_BUILDTIME call
* Fri Jul 15 2016 rpm@fthiessen.de
- Update to new upstream release 1.4.5
  * Support for new FieldOrder element and for the new
    color-related elements.
  * Required for mkvtoolnix >= 9.3.0
* Wed Dec 16 2015 olaf@aepfle.de
- Add BuildRoot: for SLE_11
* Thu Oct 22 2015 rpm@fthiessen.de
- Update to new upstream release 1.4.4 (security fix):
  * KaxInternalBlock::ReadData(): Fixed an invalid memory
  access. When reading a block group or a simple block that uses
  EBML lacing the frame sizes indicated in the lacing weren't
  checked against the available number of bytes. If the indicated
  frame size was bigger than the whole block's size the parser would
  read beyond the end of the buffer resulting in a heap information
  leak.
  * all: a couple of optimizations in the main library and a memory
  leak fix in the tests
  * build system: fix linking against libEBML
- Removed unneeded linker settings, not needed anymore in current
  mkvtoolnix version.
* Thu Feb  5 2015 coolo@suse.com
- package the changes file as its required for rebuilds
* Sun Feb  1 2015 jengelh@inai.de
- Update to new upstream release 1.4.2
  * KaxBlock::ReadData(): fixed several instances of unchecked
  memory access leading to invalid memory access/segmentation faults
  with invalid or broken data inside block groups/simple blocks.
  * KaxBlock::ReadInternalHead(): fixed a off-by-one buffer overflow
  if with EBML lacing and exactly one frame in the lace.
- Drop libmatroska-heed-ldflags.diff (no longer needed)
* Wed Aug  6 2014 jengelh@inai.de
- Add libmatroska-heed-ldflags.diff so that make places LDFLAGS
  onto the command line for generating the .so file
* Wed Aug  6 2014 jengelh@inai.de
- Set RPM groups
* Tue Feb 11 2014 dimstar@opensuse.org
- Also revert fvisibility-inlines-hidden: still breaks mkvtoolnix
  on i586.
* Thu Jan 16 2014 crrodriguez@opensuse.org
- Revert last change for now as it breaks mkvtoolnix which
  uses internal symbols :-(
  keep fvisibility-inlines-hidden though
* Sun Jan 12 2014 crrodriguez@opensuse.org
- Add C++ visibility support by simply reusing the win32
  dll code for the same purpose.
- added patches:
  * matroska-visibility.patch
* Sat Nov  2 2013 reddwarf@opensuse.org
- Update to version 1.4.1
  * Added new elements/classes DiscardPadding, CodecDelay and
    SeekPreRoll
  * The licensing information has been cleared up/unified.
  * The Makefile now contain options for specifying the destination
    base directory during installation ("DESTDIR") and for
    specifying which library types to build ("link").
  * The libraries are built without the "-ansi" and
    "-fno-gnu-keywords" flags on Linux
  * Code cleanup
- Remove matroska-noansiflag.patch. Applied upstream.
* Sat Mar 23 2013 zaitor@opensuse.org
- Update to version 1.4.0:
  + Added new elements CueDuration, CueRelativePosition,
    ChapterStringUID, VideoAlphaMode and
    DefaultDecodedFieldDuration
  + Removed the Debian build files from our package.
- Bump soname following upstream code changes.
- Rebased matroska-noansiflag.patch.
* Thu May 10 2012 crrodriguez@opensuse.org
- Do not use gcc 's -ansi flag, but whatever the compiler
  has a default.
* Sun Sep 25 2011 reddwarf@opensuse.org
- Update to version 1.3.0
  + initialize all data members
  + The KaxCodeVersion variable now resides in the library instead of being declared static in the header file.
  + make KaxChapterSegmentEditionUID an unsigned integer to match the KaxChapterEditionUID it's supposed to target
* Thu Jun 30 2011 dimstar@opensuse.org
- Update to version 1.2.0:
  + skip data from KaxBlockVirtual as it should not be used
  + use semantic generated from the specs so there is no more
    possible mismatch
- Bump suname to 4, following the source changes.
- Stop using source service, as Factory is moving to a different
  way to verify source authenticity.
* Mon Apr 18 2011 ro@suse.de
- update baselibs.conf
* Sun Jan 30 2011 reddwarf@opensuse.org
- version update to 1.1.0
  - give access to the SetParent to KaxSimpleBlock as well
  - change the placement of a MATROSKA_DLL_API so that it actually works
  - remove all references to the old/outdated/previous tag system
  - add the possibility for a DataBuffer class to use its own internal memory
  - KaxCues::AddBlockGroup() was removed as it's broken beyond repair
  - add KaxTrackOperation and related elements for combined stereo/3D tracks or joined virtual tracks
  - fix a memory leak in KaxReferenceBlock when an internal KaxBlockBlob was created
  - Increased library .so name due to binary incompatible changes in libebml
* Wed Aug  4 2010 reddwarf@opensuse.org
- remove __TIMESTAMP__ so BuildCompare can do its work
* Wed Jul 28 2010 coolo@novell.com
- fix build in renaming shared library package
* Sat Jun  5 2010 cmorve69@yahoo.es
- Update to version 1.0.0
  - Fix more issues which came to light with the recent push of
    WebM -- mostly regarding elements with unknown sizes.
* Sat May 15 2010 cmorve69@yahoo.es
- version update to 0.9.0
  - fix a memory freeing issue in KaxBlock
  - use the macros from the new libebml 0.8.0 to simplify the element definitions and avoid possible typo bugs
  - fix some building issues on Linux and MinGW
  - add matroska_init() and matroska_done() functions, necessary when used with libebml v2
  - use the new libebml iterators of EbmlMaster where possible
* Wed May 12 2010 cmorve69@yahoo.es
- added patch to "Do not try to free() pointers pointing to member
  variables" from upstream SVN. Fixes VLC crash.
* Tue Jan 13 2009 crrodriguez@suse.de
- remove static libraries
* Sat May 26 2007 ro@suse.de
- added libebml-devel to buildreq
- split off devel package
* Mon Feb 26 2007 seife@suse.de
- version update to 0.8.1
  - add support for KaxCodecState and indexing them in the cues
  - "make install" fixes
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Nov 21 2005 seife@suse.de
- version update to 0.8.0
* Wed Nov  2 2005 dmueller@suse.de
- don't build as root
* Wed Sep 28 2005 meissner@suse.de
- use RPM_OPT_FLAGS correctly.
* Tue Jul  5 2005 seife@suse.de
- version 0.7.7
* Sun Apr 17 2005 seife@suse.de
- version 0.7.6
* Mon Feb  7 2005 seife@suse.de
- version 0.7.5
* Tue Oct 26 2004 seife@suse.de
- version 0.7.4
* Thu Sep  2 2004 seife@suse.de
- add libebml to neededforbuild
* Wed Sep  1 2004 seife@suse.de
- initial submission
